@@ -11,25 +11,30 @@
     <message>
         <location filename="../notificationwidgets.cpp" line="155"/>
         <source>OK</source>
-        <translation>Okei</translation>
+        <translation>OK</translation>
     </message>
 </context>
 <context>
     <name>Notifyd</name>
     <message>
-        <location filename="../notifyd.cpp" line="272"/>
+        <location filename="../notifyd.cpp" line="274"/>
         <source>Clear All</source>
         <translation>Fjern alt</translation>
     </message>
     <message>
-        <location filename="../notifyd.cpp" line="280"/>
+        <location filename="../notifyd.cpp" line="285"/>
+        <source>Do Not Disturb</source>
+        <translation>Ikke forstyrr</translation>
+    </message>
+    <message>
+        <location filename="../notifyd.cpp" line="293"/>
         <source>Options</source>
-        <translation>Valg</translation>
+        <translation>Alternativer</translation>
     </message>
     <message numerus="yes">
-        <location filename="../notifyd.cpp" line="287"/>
-        <location filename="../notifyd.cpp" line="344"/>
-        <location filename="../notifyd.cpp" line="364"/>
+        <location filename="../notifyd.cpp" line="300"/>
+        <location filename="../notifyd.cpp" line="358"/>
+        <location filename="../notifyd.cpp" line="379"/>
         <source>%n Unattended Notification(s)</source>
         <translation>
             <numerusform>%n usett varsel</numerusform>
